@@ -695,6 +695,11 @@ module Shrink = struct
       IntTree.(make ~print:print_tree ~shrink:shrink_tree gen_tree)
       (fun tree -> IntTree.contains_only_n tree 42)
 
+  let test_gen_no_shrink =
+    Test.make ~name:"sum list = 0"
+      (set_shrink Shrink.nil (list small_int))
+      (fun xs -> List.fold_left (+) 0 xs = 0)
+
   let tests = [
     (*test_fac_issue59;*)
     big_bound_issue59;
@@ -748,6 +753,7 @@ module Shrink = struct
     (*list_equal_dupl;*)
     list_unique_elems;
     tree_contains_only_42;
+    test_gen_no_shrink;
   ]
 end
 
